@@ -172,7 +172,7 @@ class Tests:
 
     def version(self):
         """Print version and copyright info"""
-        report("spd-conf 0.9.1\n")
+        report("spd-conf 0.10.2\n")
         report(_("""Copyright (C) %d-%d Brailcom, o.p.s.
 This is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by
@@ -237,7 +237,7 @@ to be able to use Festival with Speech Dispatcher."""))
             report(_("""Python can't find the Speech Dispatcher library.
 Is it installed? This won't prevent Speech Dispatcher to work, but no
 Python applications like Orca will be able to use it.
-Search for package like python-speechd, download and install it"""))
+Search for package like python-speechd, download and install it."""))
             return False
         return True
 
@@ -632,14 +632,14 @@ Do you want to keep it?"""), False)
         self.default_output_module = question_with_suggested_answers(
             "Default output module",
             "espeak-ng",
-            ["espeak-ng", "espeak", "festival", "flite", "ivona", "pico", "espeak-generic",
+            ["espeak-ng", "espeak", "festival", "flite", "ivona", "pico",
              "espeak-ng-mbrola-generic", "espeak-mbrola-generic", "swift-generic",
-             "epos-generic", "dtk-generic", "pico-generic", "ibmtts", "cicero", "kali",
+             "epos-generic", "dtk-generic", "ibmtts", "cicero", "kali",
              "mary-generic", "baratinoo"])
 
         self.default_language = question(
-            "Default language (two-letter iso language code like \"en\" or \"cs\")",
-            "en")
+            "Default language (two/three-letter iso language code like \"en\" or \"cs\", possibly with a region qualification.)",
+            "en-US")
 
         self.default_audio_method = question_with_suggested_answers(
             "Default audio output method",
@@ -738,7 +738,7 @@ you have to start it manually to continue."""))
         """Create a complete configuration, run diagnosis and if necessary, debugging"""
 
         speechd_type = question_with_required_answers(
-            _("Do you want to create/setup a 'user' or 'system' configuration"),
+            _("Do you want to create/setup a 'user' or 'system' configuration?"),
             'user', ['user', 'system'])
 
         if speechd_type == 'user':
